Alliance Auth
============

[![Join the chat at https://gitter.im/R4stl1n/allianceauth](https://badges.gitter.im/R4stl1n/allianceauth.svg)](https://gitter.im/R4stl1n/allianceauth?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Documentation Status](https://readthedocs.org/projects/allianceauth/badge/?version=latest)](http://allianceauth.readthedocs.io/?badge=latest)
[![Build Status](https://travis-ci.org/allianceauth/allianceauth.svg?branch=master)](https://travis-ci.org/allianceauth/allianceauth)
[![Coverage Status](https://coveralls.io/repos/github/allianceauth/allianceauth/badge.svg?branch=master)](https://coveralls.io/github/allianceauth/allianceauth?branch=master)


An auth system for EVE Online to help in-game organizations manage online service access.

[Read the docs here.](http://allianceauth.rtfd.io)

[Get help on gitter](https://gitter.im/R4stl1n/allianceauth) or submit an Issue.


Active Developers:

 - [Adarnof](https://github.com/adarnof/)
 - [Basraah](https://github.com/basraah/)

Beta Testers / Bug Fixers:

 - [ghoti](https://github.com/ghoti/)
 - [mmolitor87](https://github.com/mmolitor87/)
 - [TargetZ3R0](https://github.com/TargetZ3R0)
 - [kaezon](https://github.com/kaezon/)
 - [orbitroom](https://github.com/orbitroom/)
 - [tehfiend](https://github.com/tehfiend/)

Special thanks to [Nikdoof](https://github.com/nikdoof/), as his [auth](https://github.com/nikdoof/test-auth) was the foundation for the original work on this project.

### Contributing
Make sure you have signed the [License Agreement](https://developers.eveonline.com/resource/license-agreement) by logging in at [https://developers.eveonline.com](https://developers.eveonline.com) before submitting any pull requests.